@@ -42,7 +42,7 @@ sub encode {
     my @list;
     for ( my $i = 0 ; $i < scalar(@array) ; $i++ ) {
 
-        # translate "\\n" to ""
+        # translate "\\n" to "。"
         if ( $array[$i] eq '\\' && $array[ $i + 1 ] eq 'n' ) {
             push @list, 129;
             push @list, 66;
@@ -183,17 +183,17 @@ sub mk_compclass {
 
     print "==========================================================\n";
 
-    # ե̾ɬ
+    # ファイル名は必須
     unless ($file) {
         die "usage: ./myapp_create.pl model CRUD CRUD [DBDesigner 4 File] [some modules]\n";
         return 1;
     }
 
-    # XMLե
+    # XMLファイル解析
     my $parser = new XML::Simple();
     my $tree   = $parser->XMLin($file);
 
-    # SQLȥ顦ƥץ졼ѤΥǥ쥯ȥ
+    # SQL・コントローラ・テンプレート用のディレクトリを作る
     my $schema_dir     = sprintf( "%s/sql/schema",        $helper->{'base'} );
     my $i18n_dir       = sprintf( "%s/lib/%s/I18N",       $helper->{'base'}, $helper->{'app'} );
     my $controller_dir = sprintf( "%s/lib/%s/Controller", $helper->{'base'}, $helper->{'app'} );
@@ -203,7 +203,7 @@ sub mk_compclass {
     $helper->mk_dir($controller_dir);
     $helper->mk_dir($template_dir);
 
-    # 졼ȥơ֥
+    # リレーションとテーブル一覧を取得する
     if ( ref $tree->{'METADATA'}->{'RELATIONS'}->{'RELATION'} eq 'ARRAY' ) {
         @relations = @{ $tree->{'METADATA'}->{'RELATIONS'}->{'RELATION'} };
     }
@@ -217,7 +217,7 @@ sub mk_compclass {
         push( @tables, $tree->{'METADATA'}->{'TABLES'}->{'TABLE'} );
     }
 
-    # ꤷ⥸塼Τ
+    # 指定したモジュールのみ
     my %limit;
     $limit{$_} = 1 foreach (@limited_file);
 
@@ -226,24 +226,24 @@ sub mk_compclass {
         my $class_name = $model_name;
         $class_name =~ s/Master//g;
 
-        # ꤷ⥸塼Τ
+        # 指定したモジュールのみ
         if ( scalar @limited_file ) {
             next unless ( $limit{$class_name} );
         }
 
-        # ƥơ֥
+        # 各テーブルの列一覧取得
         my @columns = @{ $table->{'COLUMNS'}->{'COLUMN'} }
           if ref $table->{'COLUMNS'}->{'COLUMN'} eq 'ARRAY';
 
-        # ƥơ֥Υǥå
+        # 各テーブルのインデックス覧取得
         my %indices;
         if ( ref( $table->{'INDICES'}->{'INDEX'} ) eq 'HASH' ) {
 
-            # ǰĤΤȤϥϥåˤʤäƤޤΤǤк
+            # 要素一個のときはハッシュになってしまうのでその対策
             my $key = $table->{'INDICES'}->{'INDEX'}->{'INDEXCOLUMNS'}->{'INDEXCOLUMN'}->{'idColumn'};
             my $val = $table->{'INDICES'}->{'INDEX'}->{'FKRefDef_Obj_id'};
 
-            # 祭̵뤹
+            # 主キーは無視する
             unless ( $val eq '-1' ) {
                 $indices{$key} = $val;
             }
@@ -253,28 +253,28 @@ sub mk_compclass {
                 my $key = $index->{'INDEXCOLUMNS'}->{'INDEXCOLUMN'}->{'idColumn'};
                 my $val = $index->{'FKRefDef_Obj_id'};
 
-                # 祭̵뤹
+                # 主キーは無視する
                 unless ( $val eq '-1' ) {
                     $indices{$key} = $val;
                 }
             }
         }
 
-        my @serials;     # 󥹰
-        my @sqls;        # SQL
-        my @settings;    # ް
+        my @serials;     # シーケンス一覧
+        my @sqls;        # SQL一覧
+        my @settings;    # スキーマ一覧
         foreach my $column (@columns) {
             my $sql;
             my @setting;
 
-            # ̾
+            # カラム名
             push @setting, ( "        " . $column->{'ColName'} );
 
-            # 
+            # 型
             if ( $column->{'AutoInc'} eq "1" ) {
 
-                # AutoInc="1" ä֥ơ֥̾_̾_seqפȤ
-                # ơ֥ Postgresql ưΤǤб
+                # AutoInc="1" だったら「テーブル名_カラム名_seq」という
+                # テーブルを Postgresql が自動作成するのでその対応
                 $sql->{'type'} = "serial";
                 push @setting, "SERIAL";
                 push @serials,
@@ -309,55 +309,55 @@ sub mk_compclass {
                 push @setting, "TEXT";
             }
 
-            # 祭ɤ
+            # 主キーかどうか
             if ( $column->{'PrimaryKey'} eq '1' ) {
                 $sql->{'primarykey'} = 1;
                 push @setting, "PRIMARY KEY";
             }
             elsif ( 'id' eq lc( $column->{'ColName'} ) ) {
 
-                # id ϼưŪ˼祭ˤ
+                # id は自動的に主キーにする
                 $sql->{'primarykey'} = 1;
                 push @setting, "PRIMARY KEY";
             }
 
-            # ǥե
+            # デフォルト値
             if ( length( $column->{'DefaultValue'} ) > 0 ) {
                 $sql->{'default'} = $column->{'DefaultValue'};
                 push @setting, sprintf( "DEFAULT '%s'", $column->{'DefaultValue'} );
             }
             elsif ( $column->{'idDatatype'} eq '14' ) {
 
-                # դϼưŪꤹ
+                # 日付は自動的に設定する
                 $sql->{'default'} = "('now'::text)::timestamp";
                 push @setting, "DEFAULT ('now'::text)::timestamp";
             }
             elsif ( $column->{'idDatatype'} eq '16' ) {
 
-                # ϼưŪꤹ
+                # 日時は自動的に設定する
                 $sql->{'default'} = "('now'::text)::timestamp";
                 push @setting, "DEFAULT ('now'::text)::timestamp";
             }
             elsif ( 'disable' eq lc( $column->{'ColName'} ) ) {
 
-                # disable ϼưŪ 0 ˤ
+                # disable は自動的に 0 にする
                 $sql->{'default'} = "0";
                 push @setting, "DEFAULT '0'";
             }
 
-            # NOT NULL 
+            # NOT NULL 制約
             if ( $column->{'NotNull'} eq '1' ) {
                 $sql->{'notnull'} = 1;
                 push @setting, "NOT NULL";
             }
             elsif ( 'disable' eq lc( $column->{'ColName'} ) ) {
 
-                # disable ϼưŪ NOT NULL ˤ
+                # disable は自動的に NOT NULL にする
                 $sql->{'notnull'} = 1;
                 push @setting, "NOT NULL";
             }
 
-            # 
+            # 参照制約
             if ( $indices{ $column->{'ID'} } ) {
                 my $relation   = $this->get_relation( $indices{ $column->{'ID'} } );
                 my $src_table  = $this->get_table( $relation->{'SrcTable'} );
@@ -374,41 +374,41 @@ sub mk_compclass {
                     $column->{'ColName'}, $src_table->{'Tablename'} );
             }
 
-            # 
+            # コメント
             if ( 'id' eq lc( $column->{'ColName'} ) ) {
 
-                # id ϼưŪ ID ˤ
+                # id は自動的に ID にする
                 push @setting, '/* ID */';
             }
             elsif ( 'disable' eq lc( $column->{'ColName'} ) ) {
 
-                # disable ϼưŪ  ˤ
-                push @setting, '/*  */';
+                # disable は自動的に 削除 にする
+                push @setting, '/* 削除 */';
             }
             else {
                 push @setting, sprintf( "/* %s */", $this->encode( $column->{'Comments'} ) );
             }
 
-            # ̾
+            # 列名の代入
             $sql->{'name'} = $column->{'ColName'};
 
-            # ̾ˤä̯˥Ѥ
+            # 列名によって微妙にカラムの説明を変える
             if ( $column->{'ColName'} eq 'id' ) {
                 $sql->{'desc'} = 'ID';
             }
             elsif ( $column->{'ColName'} eq 'disable' ) {
-                $sql->{'desc'} = 'ե饰';
+                $sql->{'desc'} = '削除フラグ';
             }
             elsif ( $column->{'ColName'} eq 'date_regist' ) {
-                $sql->{'desc'} = 'Ͽ';
+                $sql->{'desc'} = '登録日時';
             }
             elsif ( $column->{'ColName'} eq 'date_update' ) {
-                $sql->{'desc'} = '';
+                $sql->{'desc'} = '更新日時';
             }
             else {
                 $sql->{'desc'} = $this->encode( $column->{'Comments'} );
 
-                # ʤȤϥ̾ʸѴ
+                # カラムの説明がないときはカラム名を大文字に変換
                 if ( length( $sql->{'desc'} ) == 0 ) {
                     $sql->{'desc'} = uc $column->{'ColName'};
                 }
@@ -418,7 +418,7 @@ sub mk_compclass {
             push @settings, join( " ", @setting );
         }
 
-        # SQL
+        # SQL出力
         my $setting_vars;
         $setting_vars->{'table'}   = $table->{'Tablename'};
         $setting_vars->{'comment'} = $this->encode( $table->{'Comments'} );
@@ -426,7 +426,7 @@ sub mk_compclass {
         $setting_vars->{'serials'} = join( "", @serials );
         $helper->render_file( 'schema_sql', "$schema_dir/$table->{'Tablename'}.sql", $setting_vars );
 
-        # ȥ
+        # コントローラ出力
         my $controller_vars;
         $controller_vars->{'app_name'}   = $helper->{'app'};
         $controller_vars->{'path_name'}  = lc $class_name;
@@ -439,7 +439,7 @@ sub mk_compclass {
         $controller_vars->{'sqls'}       = \@sqls;
         $helper->render_file( 'controller_class', "$controller_dir/$class_name.pm", $controller_vars );
 
-        # ƥץ졼Ƚ
+        # テンプレート出力
         my $path_name = lc $class_name;
         $helper->mk_dir("$template_dir/$path_name");
         $helper->render_file( 'create_html', "$template_dir/$path_name/create.html", $controller_vars );
@@ -448,13 +448,13 @@ sub mk_compclass {
         $helper->render_file( 'list_html',   "$template_dir/$path_name/list.html",   $controller_vars );
     }
 
-    # إåեå
+    # ヘッダー・フッター出力
     my $header_footer_vars;
     $header_footer_vars->{'app_name'} = $helper->{'app'};
     $helper->render_file( 'header_html', "$template_dir/header.html", $header_footer_vars );
     $helper->render_file( 'footer_html', "$template_dir/footer.html", $header_footer_vars );
 
-    # ե
+    # 言語ファイル出力
     $helper->render_file( 'ja_po', "$i18n_dir/ja.po" );
     $helper->render_file( 'en_po', "$i18n_dir/en.po" );
 
@@ -538,7 +538,7 @@ sub setting {
     my ( $self, $c ) = @_;
     my $hash = {
         'name'     => '[% path_name %]',
-        'model'    => '[% base_name %]::[% model_name %]Master',
+        'model'    => '[% base_name %]::[% model_name %]',
         'primary'  => '[% primary %]',
         'columns'  => [qw([% columns %])],
         'default'  => '/[% path_name %]/list',
@@ -557,297 +557,158 @@ sub setting {
 1;
 
 __header_html__
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
-    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
-
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html>
   <head>
-    <meta http-equiv="content-type" content="application/xhtml+xml; charset=euc-jp" />
-    
     <title>[% app_name %]</title>
-    
+    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
+    <!-- link rel="stylesheet" href="styles.css" / -->
     <style type="text/css">
     <!--
-    /* ###### Browser-specific Styles ###### */
-    
-    /* For IE & Mozilla-based browsers: */
-    
-    .LHS {
-      margin-left: 2.5mm;
-      float: left;
-      clear: left;
-    }
-    
-    .RHS {
-      margin-right: 2.5mm;
-      float: right;
-      clear: right;
-    }
-    
-    /* For Mozilla-based (CSS2-fully complaint) browsers only: */
-    
-    [class~="LHS"] {
-      margin-left: 5mm;
-    }
-    
-    [class~="RHS"] {
-      margin-right: 5mm;
-    }
-    
-    /* ###### Body Text ###### */
-    
-    body {
-      background-color: white;
-      color: black;
-      font-family: verdana, tahoma, helvetica, arial, sans-serif;
-      font-size: 95%;
-      margin: 0;
-      background-repeat: no-repeat;
-      background-attachment: scroll;
-    }
-    
-    h1, h2, h3 {
-      font-family: "trebuchet ms", tahoma, sans-serif;
-    }
-    
-    h1 {
-      font-weight: bold;
-      font-size: 150%;
-      border-bottom-style: solid;
-      border-bottom-width: 1px;
-      padding-bottom: 0.5ex;
-    }
-    
-    img {
-      border: none;
-    }
-    
-    q {
-      font-family: tahoma, verdana, helvetica, arial, sans-serif;
-      font-weight: bold;
-      border-style: dotted;
-      border-width: 2px;
-      margin: 0 1em 1ex 1em;
-      padding: 0.5ex 0.5ex 0.5ex 1ex;
-      width: 9em;
-      float: left;
-    }
-    
-    acronym {
-      border-bottom-style: dotted;
-      border-bottom-width: 1px;
-      cursor: help;
-    }
-    
-    code {
-      font-family: "lucida console", monospace;
-      font-size: 90%;
-    }
-    
-    dt {
-      font-weight: bold;
-    }
-    
-    dd {
-      padding-bottom: 1.5em;
-    }
-    
-    #bodyText {
-      text-align: justify;
-      line-height: 1.5em;
-      margin: 10mm 5mm 0 14em;
-      padding: 0 1em 1ex 1em;
-    }
-    
-    #bodyText p {
-      padding-bottom: 2ex;
-    }
-    
-    #bodyText a {
-      text-decoration: none;
-      border-bottom-style: solid;
-      border-bottom-width: 1px;
-    }
-    
-    #bodyText a:hover {
-      border-bottom: none;
-    }
-    
-    #bodyText .topOfPage {
-      font-size: 90%;
-      font-weight: bold;
-      font-variant: small-caps;
-      text-decoration: none;
-      border: none;
-      padding-left: 1ex;
-      padding-right: 1ex;
-      float: right;
-    }
-    
-    .smallCaps {
-      font-variant: small-caps;
-    }
-    
-    /* ###### Header ###### */
-    
-    #header {
-      border-bottom-style: solid;
-      border-bottom-width: 2px;
-      height: 7.5em;
-      margin-bottom: 5mm;
-      padding: 0 2.5mm 0 5mm;
-      background-repeat: no-repeat;
-    }
-    
-    .headerTitle {
-      font-size: 300%;
-      font-weight: bold;
-      line-height: 2em;
-    }
-    
-    .menuBar {
-      float: left;
-    }
-    
-    .locBar {
-      float: right;
-    }
-    
-    .menuBar *, .locBar * {
-      text-decoration: none;
-      font-weight: bold;
-      padding-right: 1ex;
-    }
-    
-    .menuBar a:hover, .locBar a:hover {
-      text-decoration: underline;
-    }
-    
-    /* ###### Side Box ###### */
-    
-    .sideBox {
-      border-style: solid none solid none;
-      border-width: 2px 0 2px 0;
-      width: 11em;
-      margin-top: 5mm;
-    }
-    
-    .sideBox div {
-      font-weight: bold;
-      border-bottom-style: dashed;
-      border-bottom-width: 1px;
-      padding: 0.5ex 0.5em 0.5ex 0.75em;
-    }
-    
-    .sideBox a, .sideBox a:hover, .sideBox span {
-      color: black;
-      text-decoration: none;
-      line-height: 1.25em;
-      display: block;
-      padding: 1.25ex 0.5em 1.25ex 0.75em;
-    }
-    
-    .sideBox .thisPage {
-      font-weight: bold;
-    }
-    
-    /* ###### Footer ###### */
-    
-    #footer {
-      padding-top: 0.75ex;
-      padding-bottom: 0.75ex;
-      clear: left;
-    }
-    
-    #footer div {
-      font-size: 85%;
-      line-height: 1.25em;
-      text-align: right;
-      padding-right: 3mm;
-    }
-    
-    #footer a:hover {
-      text-decoration: none;
-    }
-    
-    .footerLHS {
-      float: left;
-      clear: left;
-      padding-left: 3mm;
-    }
-    
-    /* ###### General Color Scheme ###### */
-    
-    h1, h2, h3, q, #header div, #header div *, #footer *, .headerTitle, .sideBox div, .topOfPage
-    { /* Text Color: */  color: #4080ff; }
-    
-    h1, q,  #header, .sideBox, .sideBox div
-    { /* Border Color: */  border-color: #0080ff; }
-    
-    #header, .sideBox div, .sideBox a:hover, .sideBox .thisPage
-    { /* Background Color (darker): */  background-color: #e8f0ff; }
-    
-    q, .sideBox a, .sideBox span
-    { /* Background Color (lighter): */  background-color: #fafcff; }
-    
-    /* ###### Special Colors ###### */
-    
-    acronym {
-      color: blue;
-      border-bottom-color: blue;
-    }
-    
-    #bodyText a {
-      color: #4080ff;
-      border-bottom-color: #4080ff;
-    }
-    
-    #footer {
-      background-color: #f2f6ff;
-    }
+      #centre {
+      border:1px solid #202020;
+      border-bottom:0;
+      border-top:0;
+      color:#000;
+      padding:1.5em;
+      }
+
+      #conteneur {
+      background-color:#fafafa;
+      margin:1em 5%;
+      min-width:60em;
+      position:absolute;
+      width:90%;
+      }
+
+      #haut {
+      background-color:#202020;
+      height:2.4em;
+      max-height:2.4em;
+      }
+
+      #header {
+      background-color:#2D4B9B;
+      border:1px solid #fafafa;
+      color:#fafafa;
+      font-size:2em;
+      height:2.5em;
+      padding-left:2em;
+      padding-top:1em;
+      }
+
+      #pied {
+      border:1px solid #202020;
+      border-top:0;
+      padding:0.5em;
+      text-align:right;
+      }
+
+      .menuhaut {
+      font-size:1em;
+      list-style-type:none;
+      margin:0;
+      padding:0;
+      }
+
+      .menuhaut a {
+      color:#fafafa;
+      margin:0 0.4em;
+      text-decoration:none;
+      }
+
+      .menuhaut a:hover {
+      color:#FF0;
+      text-decoration:none;
+      }
+
+      .menuhaut li {
+      border-right:1px solid #fff;
+      display:inline;
+      float:left;
+      margin:0;
+      padding:0.6em 10px;
+      }
+
+      a {
+      color:#000;
+      text-decoration:underline;
+      }
+
+      body {
+      background-color:#CDCDCD;
+      font-family:Verdana, Arial, Helvetica, sans-serif;
+      font-size:0.75em;
+      }
+
+      h1 {
+      font-size:1.6em;
+      margin:0.5em 0.5em 1em 0;
+      }
+
+      h2 {
+      font-size:1.2em;
+      margin:0.8em 0.5em 0.3em 0.6em;
+      }
+
+      h3 {
+      font-size:1.1em;
+      margin:0.8em 0.5em 0.3em 0.8em;
+      }
+
+      h4 {
+      font-size:1em;
+      margin:0.7em 0.5em 0.3em 1em;
+      }
+
+      h5 {
+      font-size:0.9em;
+      margin:0.6em 0.5em 0.2em 1.5em;
+      }
+
+      p {
+      margin:1px 0.5em 0.5em 1.5em;
+      }
+
+      table {
+      border-collapse: collapse;
+      margin:1px 0.5em 0.5em 1.5em;
+      }
+
+      th {
+      background-color: #C0C0C0;
+      border: 1px solid #202020;
+      padding: 3px;
+      color: #202020;
+      }
+
+      td {
+      background-color: #FFFFFF;
+      border: 1px solid #202020;
+      padding: 3px;
+      }
     -->
     </style>
   </head>
-
   <body>
-    <div id="top"></div>
-
-    <!-- ###### Header ###### -->
-
-    <div id="header">
-      <span class="headerTitle">[% app_name %]</span>
-      <div class="menuBar">
-        <a href="/">Home</a>|
-        <a href="#">Menu1</a>|
-        <a href="#">Menu2</a>
+    <div id="conteneur">
+      <!-- header -->
+      <div id="header">[% app_name %]</div>
+      <!-- menu -->
+      <div id="haut">
+        <ul class="menuhaut">
+          <li><a href="#">menu1</a></li>
+          <li><a href="#">menu2</a></li>
+          <li><a href="#">menu3</a></li>
+        </ul>
       </div>
-    </div>
-
-    <!-- ###### Side Boxes ###### -->
-
-    <div class="sideBox LHS">
-      <div>SubMenu</div>
-      <a href="#">SubMenu1</a>
-      <a href="#">SbuMenu2</a>
-    </div>
-
-    <!-- ###### Body Text ###### -->
-
-    <div id="bodyText">
+      <!-- contents -->
+      <div id="centre">
 
 __footer_html__
-    </div>
-    
-    <!-- ###### Footer ###### -->
-
-    <div id="footer">
-      <div class="footerLHS">
-        <a href="#">SiteMap</a>
-      </div>
-      
-      <div>
-        Copyright (C) 20XX xxxx yyyy.
       </div>
+      <!-- footer -->
+      <div id="pied">Copyright (C) 2007 foobar.</div>
     </div>
   </body>
 </html>
@@ -855,8 +716,8 @@ __footer_html__
 __create_html__
 [% TAGS [- -] -%]
 [% INCLUDE template/header.html -%]
-<a class="topOfPage" href="#top" title="Top Of Page">top</a>
 <h1>[- comment -][% c.loc('New') %]</h1>
+
 [% IF c.stash.create.error -%]
 <font color="red">[% c.stash.create.message %]</font>
 [% END -%]
@@ -877,7 +738,6 @@ __create_html__
 __read_html__
 [% TAGS [- -] -%]
 [% INCLUDE template/header.html -%]
-<a class="topOfPage" href="#top" title="Top Of Page">top</a>
 <h1>[- comment -][% c.loc('Detail') %]</h1>
 
 <form>
@@ -897,7 +757,6 @@ __read_html__
 __update_html__
 [% TAGS [- -] -%]
 [% INCLUDE template/header.html -%]
-<a class="topOfPage" href="#top" title="Top Of Page">top</a>
 <h1>[- comment -][% c.loc('Edit') %]</h1>
 
 <form name="[- path_name -]" method="post" action="/[- path_name -]/update">
@@ -917,7 +776,6 @@ __update_html__
 __list_html__
 [% TAGS [- -] -%]
 [% INCLUDE template/header.html -%]
-<a class="topOfPage" href="#top" title="Top Of Page">top</a>
 <h1>[- comment -][% c.loc('List') %]</h1>
 
 <form>
@@ -945,28 +803,28 @@ __list_html__
 
 __ja_po__
 msgid "New"
-msgstr ""
+msgstr "新規"
 
 msgid "Detail"
-msgstr "ܺ"
+msgstr "詳細"
 
 msgid "Edit"
-msgstr "Խ"
+msgstr "編集"
 
 msgid "Delete"
-msgstr ""
+msgstr "削除"
 
 msgid "List"
-msgstr ""
+msgstr "一覧"
 
 msgid "Add"
-msgstr "ɲ"
+msgstr "追加"
 
 msgid "Update"
-msgstr ""
+msgstr "更新"
 
 msgid "Delete"
-msgstr ""
+msgstr "削除"
 
 __en_po__
 msgid "New"
